Combinatorial and Discrete Geometry
===================================

Sage includes classes for hyperplane arrangements, polyhedra, toric varieties
(including polyhedral cones and fans), triangulations and some other helper
classes and functions.

Hyperplane arrangements
-----------------------

.. toctree::
   :maxdepth: 1

   sage/geometry/hyperplane_arrangement/arrangement
   sage/geometry/hyperplane_arrangement/ordered_arrangement
   sage/geometry/hyperplane_arrangement/library
   sage/geometry/hyperplane_arrangement/hyperplane
   sage/geometry/hyperplane_arrangement/affine_subspace
   sage/geometry/hyperplane_arrangement/plot

Polyhedral computations
-----------------------

Polyhedra
~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/geometry/polyhedron/library
   sage/geometry/polyhedron/constructor
   sage/geometry/polyhedron/parent
   sage/geometry/polyhedron/representation
   sage/geometry/polyhedron/plot
   sage/geometry/polyhedron/face
   sage/geometry/polyhedron/cdd_file_format
   sage/geometry/polyhedron/modules/formal_polyhedra_module

Lattice polyhedra
~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/geometry/lattice_polytope
   sage/geometry/polyhedron/lattice_euclidean_group_element
   sage/geometry/polyhedron/palp_database
   sage/geometry/polyhedron/ppl_lattice_polygon
   sage/geometry/polyhedron/ppl_lattice_polytope
   sage/geometry/polyhedron/generating_function

Combinatorial Polyhedra
~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/geometry/polyhedron/combinatorial_polyhedron/base
   sage/geometry/polyhedron/combinatorial_polyhedron/combinatorial_face
   sage/geometry/polyhedron/combinatorial_polyhedron/polyhedron_face_lattice
   sage/geometry/polyhedron/combinatorial_polyhedron/face_iterator
   sage/geometry/polyhedron/combinatorial_polyhedron/list_of_faces
   sage/geometry/polyhedron/combinatorial_polyhedron/conversions


Polyhedral complexes
~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/geometry/polyhedral_complex

Toric geometry
~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/geometry/toric_lattice
   sage/geometry/cone
   sage/geometry/cone_catalog
   sage/geometry/cone_critical_angles
   sage/geometry/fan
   sage/geometry/fan_morphism
   sage/geometry/point_collection
   sage/geometry/toric_plotter

.. ONLY:: feature_gfan

   .. toctree::
      :maxdepth: 1

      sage/rings/polynomial/groebner_fan

Base classes for polyhedra
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/geometry/polyhedron/base0
   sage/geometry/polyhedron/base1
   sage/geometry/polyhedron/base2
   sage/geometry/polyhedron/base3
   sage/geometry/polyhedron/base4
   sage/geometry/polyhedron/base5
   sage/geometry/polyhedron/base6
   sage/geometry/polyhedron/base7
   sage/geometry/polyhedron/base
   sage/geometry/polyhedron/base_QQ
   sage/geometry/polyhedron/base_ZZ
   sage/geometry/polyhedron/base_RDF

Backends for Polyhedra
~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/geometry/polyhedron/backend_cdd
   sage/geometry/polyhedron/backend_cdd_rdf
   sage/geometry/polyhedron/backend_field
   sage/geometry/polyhedron/backend_number_field
   sage/geometry/polyhedron/backend_normaliz
   sage/geometry/polyhedron/backend_polymake
   sage/geometry/polyhedron/backend_ppl
   sage/geometry/polyhedron/double_description
   sage/geometry/polyhedron/double_description_inhomogeneous


Triangulations
--------------

.. toctree::
   :maxdepth: 1

   sage/geometry/triangulation/point_configuration
   sage/geometry/triangulation/base
   sage/geometry/triangulation/element


Miscellaneous
-------------

.. toctree::
   :maxdepth: 1

   sage/geometry/abc
   sage/geometry/convex_set
   sage/geometry/linear_expression
   sage/geometry/newton_polygon
   sage/geometry/relative_interior
   sage/geometry/ribbon_graph
   sage/geometry/pseudolines
   sage/geometry/voronoi_diagram

Helper functions
----------------

.. toctree::
   :maxdepth: 1

   sage/geometry/fan_isomorphism
   sage/geometry/hasse_diagram
   sage/geometry/integral_points
   sage/geometry/hyperplane_arrangement/check_freeness

.. include:: ../footer.txt
